import ColFooter from '@/components/col-footer'
import ColHeader from '@/components/col-header'
import { ElConfigProvider, ElDialog } from 'element-plus'
import { zhCn } from '@/helpers/zhCn'
import { defineComponent } from 'vue'
import { RouterView } from 'vue-router'
import Login from './login'
import styles from './App.module.less'
import { state } from '@/state'
import { getAuth, getUserType } from '@/helpers/utils'
import request from '@/helpers/request'

export default defineComponent({
  name: 'App',
  async mounted() {
    const token = getAuth()
    const userType = getUserType()
    // 判断是否有token，token和userType 判断是否登录
    if (!token) {
      return
    }

    try {
      console.log(userType)
      const url =
        userType === 'TEACHER'
          ? '/api-website/teacher/queryUserInfo'
          : '/api-website/student/queryUserInfo'
      const res = await request.get(url)
      state.user.data = res.data || {}

      // 登录状态
      state.user.status = 'login'
    } catch {
      state.user.status = 'init'
    }
  },
  render() {
    return (
      <>
        <ColHeader />
        <ElConfigProvider locale={zhCn}>
          <RouterView></RouterView>
        </ElConfigProvider>
        <ColFooter />
        {/* 登录弹窗 */}
        <div class={styles.loginContainer}>
          <ElDialog
            modelValue={state.loginPopupStatus}
            onUpdate:modelValue={val => (state.loginPopupStatus = val)}
            closeOnClickModal={false}
            closeOnPressEscape={false}
          >
            {state.loginPopupStatus && (
              <Login
                onClose={() => {
                  clearTimeout(state.loginPopupTimer)
                  state.loginPopupStatus = false
                }}
              />
            )}
          </ElDialog>
        </div>
      </>
    )
  }
})
